@@ -11,9 +11,9 @@ mkdir -p build && cd build
 MOD_PREFIX=$PWD/install
 CXXFLAGS="-Wall -Wextra -Werror -D_GLIBCXX_ASSERTIONS" ${ARCH}-w64-mingw32-cmake -DUSE_SPHINX=OFF -DUSE_SALOME=OFF \
   -DCMAKE_INSTALL_PREFIX=${MOD_PREFIX} \
-  -DPYTHON_INCLUDE_DIR=${MINGW_PREFIX}/include/python${PYMAJMIN} \
-  -DPYTHON_LIBRARY=${MINGW_PREFIX}/lib/libpython${PYMAJMIN}.dll.a \
-  -DPYTHON_EXECUTABLE=/usr/bin/${ARCH}-w64-mingw32-python${PYMAJMIN}-bin \
+  -DPython_INCLUDE_DIR=${MINGW_PREFIX}/include/python${PYMAJMIN} \
+  -DPython_LIBRARY=${MINGW_PREFIX}/lib/libpython${PYMAJMIN}.dll.a \
+  -DPython_EXECUTABLE=/usr/bin/${ARCH}-w64-mingw32-python${PYMAJMIN}-bin \
   -DSWIG_COMPILE_FLAGS="-Wno-error=unused-parameter" \
   -DCMAKE_UNITY_BUILD=ON -DCMAKE_UNITY_BUILD_BATCH_SIZE=32 /io
 make install
@@ -21,7 +21,7 @@ ${ARCH}-w64-mingw32-strip --strip-unneeded ${MOD_PREFIX}/bin/*.dll ${MOD_PREFIX}
 make tests
 cp ${MOD_PREFIX}/bin/*.dll ${MOD_PREFIX}/Lib/site-packages/persalys/
 cp ${MINGW_PREFIX}/bin/*.dll ${MOD_PREFIX}/bin
-WINEPATH="${MINGW_PREFIX}/bin;${MOD_PREFIX}/bin" xvfb-run -s "-screen 0 1024x768x24" ctest --output-on-failure --timeout 200 ${MAKEFLAGS}
+OPENTURNS_NUM_THREADS=2 WINEPATH="${MINGW_PREFIX}/bin;${MOD_PREFIX}/bin" xvfb-run -s "-screen 0 1024x768x24" ctest --output-on-failure --timeout 200 ${MAKEFLAGS}
 
 cp -r ${MINGW_PREFIX}/lib/qt/plugins/{platforms,imageformats} ${MOD_PREFIX}/lib
 cp -rv ${MINGW_PREFIX}/bin/paraview*/plugins/BagPlotViewsAndFilters ${MOD_PREFIX}/bin
@@ -42,8 +42,8 @@ cp /usr/${ARCH}-w64-mingw32/bin/*.dll Lib/site-packages/openturns
 cp /usr/${ARCH}-w64-mingw32/etc/openturns/openturns.conf Lib/site-packages/openturns
 rm Lib/site-packages/openturns/{libvtk,libboost,libLLVM,Qt,python}*.dll
 cp -rv /usr/${ARCH}-w64-mingw32/Lib/site-packages/otmorris Lib/site-packages
-curl -fSsL https://anaconda.org/conda-forge/pyfmi/2.9.8/download/win-64/pyfmi-2.9.8-py310h9b08ddd_1.tar.bz2 | tar xj
-curl -fSsL https://anaconda.org/conda-forge/assimulo/3.3/download/win-64/assimulo-3.3-py310h9e5cad0_1.tar.bz2 | tar xj
+curl -fSsL https://anaconda.org/conda-forge/pyfmi/2.10.4/download/win-64/pyfmi-2.10.4-py311h59ca53f_0.conda | bsdtar -x && tar -xf pkg-pyfmi-2.10.4-py311h59ca53f_0.tar.zst
+curl -fSsL https://anaconda.org/conda-forge/assimulo/3.4/download/win-64/assimulo-3.4-py311h0425702_0.conda | bsdtar -x && tar -xf pkg-assimulo-3.4-py311h0425702_0.tar.zst
 cd Lib
 curl -fSsL https://anaconda.org/conda-forge/otfmi/0.15/download/noarch/otfmi-0.15-pyh6c4a22f_0.tar.bz2 | tar xj
 cd site-packages
@@ -54,9 +54,9 @@ curl -fSsL https://pypi.io/packages/py2.py3/p/pytz/pytz-2021.3-py2.py3-none-any.
 curl -fSsL https://pypi.io/packages/py2.py3/p/python_dateutil/python_dateutil-2.8.2-py2.py3-none-any.whl | bsdtar -xf-
 curl -fSsL https://pypi.io/packages/py3/d/dill/dill-0.3.6-py3-none-any.whl | bsdtar -xf-
 curl -fsSL https://pypi.io/packages/py3/s/setuptools/setuptools-49.2.0-py3-none-any.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp310/n/numpy/numpy-1.22.4-cp310-cp310-win_amd64.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp310/s/scipy/scipy-1.8.1-cp310-cp310-win_amd64.whl | bsdtar -xf-
-curl -fsSL https://pypi.io/packages/cp310/p/pandas/pandas-1.5.1-cp310-cp310-win_amd64.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp311/n/numpy/numpy-1.23.5-cp311-cp311-win_amd64.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp311/s/scipy/scipy-1.9.3-cp311-cp311-win_amd64.whl | bsdtar -xf-
+curl -fsSL https://pypi.io/packages/cp311/p/pandas/pandas-1.5.3-cp311-cp311-win_amd64.whl | bsdtar -xf-
 cd ../..
 mkdir Scripts && echo -e 'import sys\nfrom pip import main\nsys.exit(main())\n' > Scripts/pip.py && echo -e 'python %~dp0pip.py %*' > Scripts/pip.bat
 cd /tmp/build
