@@ -2,7 +2,7 @@
 /**
  *  @brief base tools
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -250,10 +250,13 @@ Sample Tools::ImportSample(const String& fileName)
   std::vector< String > separatorsList(3);
   separatorsList = {" ", ",", ";"};
   Sample sampleFromFile;
+  Sample testSample;
 
   std::vector<String> numSep(2);
   numSep = {".", ","};
 
+  UnsignedInteger maxNumberOfElements = 0;
+
   for (UnsignedInteger j = 0; j < numSep.size(); ++ j) {
     for (UnsignedInteger i = 0; i < separatorsList.size(); ++ i) {
       if (separatorsList[i] == numSep[j])
@@ -261,39 +264,54 @@ Sample Tools::ImportSample(const String& fileName)
       try
       {
         // import sample from the file
-        sampleFromFile = Sample::ImportFromTextFile(fileName, separatorsList[i], 0, numSep[j]);
+        testSample = Sample::ImportFromTextFile(fileName, separatorsList[i], 0, numSep[j]);
       }
       catch (const InternalException &)
       {
         // Locale not available
-        sampleFromFile.clear();
+        testSample.clear();
+      }
+      // Select num/col separator pair leading to the largest sample
+      if (testSample.getSize() * testSample.getDimension() > maxNumberOfElements)
+      {
+        maxNumberOfElements = testSample.getSize() * testSample.getDimension();
+        sampleFromFile = testSample;
       }
-      if (sampleFromFile.getSize())
-        break;
     }
-    if (sampleFromFile.getSize())
-      break;
   }
+
   if (!sampleFromFile.getSize())
     throw InvalidArgumentException(HERE) << "The file " << fileName << " does not contain a sample and/or the file encoding is not valid (use utf-8)";
 
   // check description encoding : only utf-8 is valid
-  const String descriptionStr = sampleFromFile.getDescription().__str__();
+  String descriptionStr = sampleFromFile.getDescription().__str__();
+  // if not, try ISO-8859 -> UTF8 conversion
   if (!IsUTF8(descriptionStr.c_str(), descriptionStr.size()))
-    throw InvalidArgumentException(HERE) << "The file must contain utf-8 characters";
+  {
+    Description newDesc;
+    for(UnsignedInteger i=0; i < sampleFromFile.getDescription().getSize(); ++i)
+    {
+      descriptionStr = sampleFromFile.getDescription()[i];
+      const String convertedStr = boost::locale::conv::to_utf<char>(descriptionStr,"Latin1");
+      if (!IsUTF8(convertedStr.c_str(), convertedStr.size()))
+        throw InvalidArgumentException(HERE) << "The file must contain utf-8 or ISO-8859 characters";
+      newDesc.add(convertedStr);
+    }
+    sampleFromFile.setDescription(newDesc);
+  }
 
   // deduplicate identifiers
-  std::map<String, int> occurences;
+  std::map<String, int> occurrences;
   Description description(sampleFromFile.getDescription());
   for (UnsignedInteger i = 0; i < description.getSize(); ++ i)
   {
-    std::map<String, int>::iterator it = occurences.find(description[i]);
-    if (it == occurences.end())
-      occurences[description[i]] = 1;
+    std::map<String, int>::iterator it = occurrences.find(description[i]);
+    if (it == occurrences.end())
+      occurrences[description[i]] = 1;
     else
     {
-      ++ occurences[description[i]];
-      description[i] = (OSS() << description[i] << "_" << occurences[description[i]]);
+      ++ occurrences[description[i]];
+      description[i] = (OSS() << description[i] << "_" << occurrences[description[i]]);
     }
   }
   sampleFromFile.setDescription(description);
@@ -440,6 +458,20 @@ void Tools::ComputeBounds(const InputCollection& inputs, Point& startingPoint, I
   bounds.setUpperBound(upperBounds);
 }
 
+String Tools::GetNormalizedVariable(const String& variable)
+{
+  return std::regex_replace(variable, std::regex("[^0-9a-zA-Z_]"), "_");
+}
+
+Description Tools::GetNormalizedVariables(const Description& variables)
+{
+  Description normVariables(variables.getSize());
+  for (UnsignedInteger i = 0; i < variables.getSize(); ++ i)
+  {
+    normVariables[i] = GetNormalizedVariable(variables[i]);
+  }
+  return normVariables;
+}
 
 // TimeCriteria methods
 
