@@ -2,7 +2,7 @@
 /**
  *  @brief Class to define kriging
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -153,8 +153,8 @@ void KrigingAnalysis::launch()
   if (getCovarianceModel().getInputDimension() != inputDimension)
     throw InvalidArgumentException(HERE) << "The covariance model spatial dimension (" << getCovarianceModel().getInputDimension()
                                          << ") must be equal to the number of effective inputs (" << inputDimension << ")";
-  if (getBasis().getDimension() != inputDimension)
-    throw InvalidArgumentException(HERE) << "The basis dimension (" << getBasis().getDimension()
+  if (getBasis().getInputDimension() != inputDimension)
+    throw InvalidArgumentException(HERE) << "The basis dimension (" << getBasis().getInputDimension()
                                          << ") must be equal to the number of effective inputs (" << inputDimension << ")";
   if (testSampleValidation() && inputSize * getTestSampleValidationPercentageOfPoints() / 100 < 3)
     throw InvalidArgumentException(HERE) << "Test sample validation: The test sample must contain at least three points. Here size * k / 100 = " << (inputSize * getTestSampleValidationPercentageOfPoints() / 100);
@@ -182,10 +182,10 @@ void KrigingAnalysis::launch()
 
     // normalization was removed in 1.16
     const Point mean(effectiveInputSample.computeMean());
-    const Point stddev(effectiveInputSample.computeStandardDeviation());
+    const Point stddevInput(effectiveInputSample.computeStandardDeviation());
     SquareMatrix linear(inputDimension);
     for (UnsignedInteger j = 0; j < inputDimension; ++ j)
-        linear(j, j) = (std::abs(stddev[j]) > 1e-12) ? 1.0 / stddev[j] : 1.0;
+        linear(j, j) = (std::abs(stddevInput[j]) > 1e-12) ? 1.0 / stddevInput[j] : 1.0;
     const Point zero(inputDimension, 0.0);
     normalization_ = LinearFunction(mean, zero, linear);
 
@@ -376,7 +376,7 @@ void KrigingAnalysis::computeAnalyticalValidation(MetaModelAnalysisResult& resul
   const SquareMatrix K(C * C.transpose());
 
   // F
-  const Basis basis = krigingResult.getBasisCollection()[0];
+  const Basis basis = krigingResult.getBasis();
   const UnsignedInteger basisDim = basis.getSize();
   Sample F(size, 0);
   for (UnsignedInteger i = 0; i < basisDim; ++i)
@@ -439,7 +439,7 @@ Parameters KrigingAnalysis::getParameters() const
   param.add("Scale", getCovarianceModel().getScale());
   param.add("Amplitude", getCovarianceModel().getAmplitude());
   String basisType("Constant");
-  const UnsignedInteger dim = getBasis().getDimension();
+  const UnsignedInteger dim = getBasis().getInputDimension();
   if (getBasis().getSize() == (dim + 1))
     basisType = "Linear";
   else if (getBasis().getSize() == ((dim + 1) * (dim + 2) / 2))
@@ -479,7 +479,7 @@ String KrigingAnalysis::getPythonScript() const
   }
   // basis
   const UnsignedInteger effectiveInputDim = getCovarianceModel().getScale().getSize();
-  const UnsignedInteger basisDim = getBasis().getDimension();
+  const UnsignedInteger basisDim = getBasis().getInputDimension();
 
   oss << getName() << ".setBasis(";
   if (getBasis().getSize() == (basisDim + 1))
