@@ -2,7 +2,7 @@
 /**
  *  @brief Multi-objective optimization of a physical model
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -73,12 +73,21 @@ namespace PERSALYS
     return oss;
   }
 
-  Description MultiObjectiveOptimizationAnalysis::GetSolverNames(const Interval& bounds, const Indices& types)
+  Description MultiObjectiveOptimizationAnalysis::GetSolverNames(const Interval& bounds,
+                                                                 const Indices& types,
+                                                                 const Function& eqFunc,
+                                                                 const Function& ineqFunc)
   {
     // Dummy function to match a multi objective problem
-    OptimizationProblem problem(SymbolicFunction(Description(bounds.getDimension(), "x"), Description(bounds.getDimension(), "x^2")), Function(), Function(), bounds);
+    Function func = SymbolicFunction(Description::BuildDefault(bounds.getDimension(), "x"),
+                                     Description(bounds.getDimension(), "x0^2"));
+    OptimizationProblem problem(func, Function(), Function(), bounds);
     if (types.getSize())
       problem.setVariablesType(types);
+    if (eqFunc.getInputDimension())
+      problem.setEqualityConstraint(func);
+    if (ineqFunc.getInputDimension())
+      problem.setInequalityConstraint(func);
     return OptimizationAlgorithm::GetAlgorithmNames(problem);
   }
 
@@ -228,18 +237,39 @@ namespace PERSALYS
     moResult_ = MultiObjectiveOptimizationAnalysisResult();
 
     // initialize final pop sample
+    // X | Y | C_i | _feasibility_ | _front_index_
+
     Sample finalPop = solver.getResult().getFinalPoints();
     finalPop.stack(solver.getResult().getFinalValues());
-    finalPop.stack(Sample(finalPop.getSize(), Point(1, -1)));
     Description finalPopDesc = getVariableInputs();
     finalPopDesc.add(getInterestVariables());
-    finalPopDesc.add(Description(1, "_front_index_"));
 
-    // If constraints, add feasibility
-    if (problem.getEqualityConstraint().getInputDimension() || problem.getInequalityConstraint().getInputDimension()) {
+    // If constraints, add them and feasibility
+    const Bool isConstrained = problem.getEqualityConstraint().getInputDimension() ||
+      problem.getInequalityConstraint().getInputDimension();
+
+    if (isConstrained)
+    {
+      // Build constraints sample
+      for (UnsignedInteger i=0; i<getRawEquations().getSize(); ++i)
+      {
+        std::regex variable("([_a-zA-Z][_a-zA-Z0-9]*)");
+        std::smatch match;
+        std::regex_search(getRawEquations()[i], match, variable);
+        // If constraint variable is not already a model output
+        if (!finalPopDesc.contains(match[1]))
+        {
+          finalPopDesc.add(Description(1, match[1]));
+          finalPop.stack(getPhysicalModel().getFunction(Description(1, match[1]))(solver.getResult().getFinalPoints()));
+        }
+      }
       finalPop.stack(Sample(finalPop.getSize(), Point(1, 0)));
       finalPopDesc.add(Description(1, "_feasibility_"));
     }
+
+    // add fronts last
+    finalPop.stack(Sample(finalPop.getSize(), Point(1, -1)));
+    finalPopDesc.add(Description(1, "_front_index_"));
     finalPop.setDescription(finalPopDesc);
 
     // build fronts sample collection
@@ -252,20 +282,23 @@ namespace PERSALYS
       fronts[i].setDescription(getInterestVariables());
       // add front index and feasibility to final pop sample last 2 columns
       for (UnsignedInteger j=0; j<fronti.getSize(); ++j) {
-        finalPop(fronti[j], finalPop.getDimension() - 2) = i;
-        const Point point = solver.getResult().getFinalPoints()[fronti[j]];
-        bool isFeasible = true;
-        if (problem.getEqualityConstraint().getInputDimension()) {
-          for (UnsignedInteger k=0; k<problem.getEqualityConstraint().getOutputDimension(); ++k) {
-            isFeasible &= std::abs(problem.getEqualityConstraint()(point)[k]) < getMaximumConstraintError();
+        finalPop(fronti[j], finalPop.getDimension() - 1) = i;
+        if (isConstrained)
+        {
+          const Point point = solver.getResult().getFinalPoints()[fronti[j]];
+          bool isFeasible = true;
+          if (problem.getEqualityConstraint().getInputDimension()) {
+            for (UnsignedInteger k=0; k<problem.getEqualityConstraint().getOutputDimension(); ++k) {
+              isFeasible &= std::abs(problem.getEqualityConstraint()(point)[k]) < getMaximumConstraintError();
+            }
           }
-        }
-        if (problem.getInequalityConstraint().getInputDimension()) {
-          for (UnsignedInteger k=0; k<problem.getInequalityConstraint().getOutputDimension(); ++k) {
-            isFeasible &= problem.getInequalityConstraint()(point)[k] > 0.0;
+          if (problem.getInequalityConstraint().getInputDimension()) {
+            for (UnsignedInteger k=0; k<problem.getInequalityConstraint().getOutputDimension(); ++k) {
+              isFeasible &= problem.getInequalityConstraint()(point)[k] > 0.0;
+            }
           }
+          finalPop(fronti[j], finalPop.getDimension() - 2) = (int)isFeasible;
         }
-        finalPop(fronti[j], finalPop.getDimension() - 1) = (int)isFeasible;
       }
     }
     moResult_.setFinalPop(finalPop);
