@@ -2,7 +2,7 @@
 /**
  *  @brief Optimization of a physical model
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -88,6 +88,7 @@ std::map<OT::String, AlgorithmProperty> OptimizationAnalysis::AlgorithmDictionar
    {"B-OA",                         AlgorithmProperty(Locality::Global, Derivative::None,  OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Bonmin.html"))},
    {"B-QG",                         AlgorithmProperty(Locality::Global, Derivative::None,  OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Bonmin.html"))},
    {"B-Hyb",                        AlgorithmProperty(Locality::Global, Derivative::None,  OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Bonmin.html"))},
+   {"B-Ecp",                        AlgorithmProperty(Locality::Global, Derivative::None,  OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Bonmin.html"))},
    {"B-iFP",                        AlgorithmProperty(Locality::Global, Derivative::None,  OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Bonmin.html"))},
    {"Ipopt",                        AlgorithmProperty(Locality::Local,  Derivative::First, OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Ipopt.html"))},
    {"LEVENBERG_MARQUARD",           AlgorithmProperty(Locality::Global, Derivative::First, OT::String("http://openturns.github.io/openturns/latest/user_manual/_generated/openturns.Ceres.html"))},
@@ -114,19 +115,23 @@ Description OptimizationAnalysis::GetSolverNames()
   return OptimizationAlgorithm::GetAlgorithmNames(problem);
 }
 
-Description OptimizationAnalysis::GetSolverNames(const Interval& bounds, const Indices& types)
+Description OptimizationAnalysis::GetSolverNames(const Interval& bounds,
+                                                 const Indices& types,
+                                                 const Function& eqFunc,
+                                                 const Function& ineqFunc)
 {
   // Dummy non-linear function respecting bounds dimension
-  OptimizationProblem problem(SymbolicFunction(Description(bounds.getDimension(), "x"), Description(1, "x^2")), Function(), Function(), bounds);
+  Function func = SymbolicFunction(Description::BuildDefault(bounds.getDimension(), "x"),
+                                   Description(1, "x0^2"));
+  OptimizationProblem problem(func, Function(), Function(), bounds);
   if (types.getSize())
     problem.setVariablesType(types);
+  if (eqFunc.getInputDimension())
+    problem.setEqualityConstraint(func);
+  if (ineqFunc.getInputDimension())
+    problem.setInequalityConstraint(func);
   Description names(OptimizationAlgorithm::GetAlgorithmNames(problem));
 
-  // drop B-iFP
-  const UnsignedInteger index = names.find("B-iFP");
-  if (index < names.getSize())
-    names.erase(names.begin() + index);
-
   // drop pagmo algos as they are parametrized by a sample instead of a single point
   const Description pagmoNames(Pagmo::GetAlgorithmNames());
   for (UnsignedInteger i = 0; i < pagmoNames.getSize(); ++ i)
@@ -279,56 +284,57 @@ OptimizationProblem OptimizationAnalysis::defineProblem()
   const UnsignedInteger nbInputs = getPhysicalModel().getInputDimension();
 
   Description allVar(variableInputs_);
-    allVar.add(inputNames_);
-    for (UnsignedInteger i = 0; i < allVar.getSize(); ++i)
+  allVar.add(inputNames_);
+
+  for (UnsignedInteger i = 0; i < allVar.getSize(); ++i)
+  {
+    if (!getPhysicalModel().hasInputNamed(allVar[i]))
+      throw InvalidArgumentException(HERE) << "The physical model does not contain an input variable named " << allVar[i];
+  }
+
+  // get bounds and fixed inputs values
+  if (getBounds().getDimension() != nbInputs)
+    throw InvalidArgumentException(HERE) << "The interval's dimension must be equal to the number of model's inputs";
+  Indices fixedInputsIndices;
+  Point fixedInputsValues;
+  Indices variablesType;
+  variableInputsIndices_ = Indices();
+  variableInputsValues_ = Point();
+  for (UnsignedInteger i = 0; i < nbInputs; ++i)
+  {
+    if (!variableInputs_.contains(modelInputNames[i]))
     {
-      if (!getPhysicalModel().hasInputNamed(allVar[i]))
-        throw InvalidArgumentException(HERE) << "The physical model does not contain an input variable named " << allVar[i];
+      fixedInputsIndices.add(i);
+      fixedInputsValues.add(startingPoint_[i]);
     }
-
-    // get bounds and fixed inputs values
-    if (getBounds().getDimension() != nbInputs)
-      throw InvalidArgumentException(HERE) << "The interval's dimension must be equal to the number of model's inputs";
-    Indices fixedInputsIndices;
-    Point fixedInputsValues;
-    Indices variablesType;
-    variableInputsIndices_ = Indices();
-    variableInputsValues_ = Point();
-    for (UnsignedInteger i = 0; i < nbInputs; ++i)
+    else
     {
-      if (!variableInputs_.contains(modelInputNames[i]))
-      {
-        fixedInputsIndices.add(i);
-        fixedInputsValues.add(startingPoint_[i]);
-      }
-      else
-      {
-        variableInputsIndices_.add(i);
-        variablesType.add(variablesType_[i]);
-        variableInputsValues_.add(startingPoint_[i]);
-      }
+      variableInputsIndices_.add(i);
+      variablesType.add(variablesType_[i]);
+      variableInputsValues_.add(startingPoint_[i]);
     }
+  }
 
-    // check bounds
-    if (bounds_.getMarginal(variableInputsIndices_).isEmpty())
-      throw InvalidArgumentException(HERE) << "The lower bounds must be less than the upper bounds";
+  // check bounds
+  if (bounds_.getMarginal(variableInputsIndices_).isEmpty())
+    throw InvalidArgumentException(HERE) << "The lower bounds must be less than the upper bounds";
 
-    // set objective
-    Function objective = getPhysicalModel().getFunction(getInterestVariables());
-    Function equalityConstraints = getEqualityConstraints();
-    Function inequalityConstraints = getInequalityConstraints();
-    if (fixedInputsIndices.getSize()) {
-      objective = ParametricFunction(objective, fixedInputsIndices, fixedInputsValues);
-      if (equalityConstraints.getInputDimension())
-        equalityConstraints = ParametricFunction(equalityConstraints, fixedInputsIndices, fixedInputsValues);
-      if (inequalityConstraints.getInputDimension())
-        inequalityConstraints = ParametricFunction(inequalityConstraints, fixedInputsIndices, fixedInputsValues);
-    }
+  // set objective
+  Function objective = getPhysicalModel().getFunction(getInterestVariables());
+  Function equalityConstraints = getEqualityConstraints();
+  Function inequalityConstraints = getInequalityConstraints();
+  if (fixedInputsIndices.getSize()) {
+    objective = ParametricFunction(objective, fixedInputsIndices, fixedInputsValues);
+    if (equalityConstraints.getInputDimension())
+      equalityConstraints = ParametricFunction(equalityConstraints, fixedInputsIndices, fixedInputsValues);
+    if (inequalityConstraints.getInputDimension())
+      inequalityConstraints = ParametricFunction(inequalityConstraints, fixedInputsIndices, fixedInputsValues);
+  }
 
-    // set OptimizationProblem
-    OptimizationProblem problem(objective, equalityConstraints, inequalityConstraints, bounds_.getMarginal(variableInputsIndices_));
-    problem.setVariablesType(variablesType);
-    return problem;
+  // set OptimizationProblem
+  OptimizationProblem problem(objective, equalityConstraints, inequalityConstraints, bounds_.getMarginal(variableInputsIndices_));
+  problem.setVariablesType(variablesType);
+  return problem;
 
 }
 
@@ -534,14 +540,36 @@ Function OptimizationAnalysis::transformEquations(Description& eqs)
 {
   if (!eqs.getSize())
     return Function();
-  Description vars = getPhysicalModel().getInputNames();
-  vars.add(getPhysicalModel().getOutputNames());
+  // Variables collection to construct constraints composed function
+  const Description outputs = getPhysicalModel().getOutputNames();
+  Description inputs;
+  for (UnsignedInteger i=0; i<getPhysicalModel().getInputNames().getSize(); ++i)
+  {
+    // Look if variable is defined as both an input and output
+    if(!outputs.contains(getPhysicalModel().getInputNames()[i]))
+      inputs.add(getPhysicalModel().getInputNames()[i]);
+    // If given variable 'X' is an  output, define a dummy 'X0' input variable
+    else
+    {
+      const String varName = getPhysicalModel().getInputNames()[i];
+      int j = 0;
+      while (getPhysicalModel().hasInputNamed((OSS() << varName << j).str()))
+        ++j;
+      inputs.add((OSS() << varName << j).str());
+    }
+  }
+
+  Description vars;
+  vars.add(inputs);
+  vars.add(outputs);
 
   // Functions construction
   // Aggregated(X->X, X->Y)
   Collection<Function> funcModelColl;
+  const Description modelInputs = getPhysicalModel().getInputNames();
   // X->X
-  funcModelColl.add(SymbolicFunction(getPhysicalModel().getInputNames(), getPhysicalModel().getInputNames()));
+  funcModelColl.add(SymbolicFunction(Tools::GetNormalizedVariables(modelInputs),
+                                     Tools::GetNormalizedVariables(modelInputs)));
   // X->Y
   funcModelColl.add(getPhysicalModel().getFunction());
   AggregatedFunction funcModel = AggregatedFunction(funcModelColl);
@@ -549,7 +577,8 @@ Function OptimizationAnalysis::transformEquations(Description& eqs)
   // Aggregated C_i
   Collection<Function> funcC_i;
   for(UnsignedInteger i=0; i<eqs.getSize(); ++i)
-    funcC_i.add(SymbolicFunction(vars, Description(1, eqs[i])));
+    funcC_i.add(SymbolicFunction(Tools::GetNormalizedVariables(vars),
+                                 Description(1, eqs[i])));
 
   return ComposedFunction(AggregatedFunction(funcC_i), funcModel) ;
 }
