@@ -2,7 +2,7 @@
 /**
  *  @brief QStandardItem, observer of analysis
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,6 +23,7 @@
 #include "persalys/DesignOfExperimentEvaluation.hxx"
 #include "persalys/FunctionalChaosAnalysis.hxx"
 #include "persalys/KrigingAnalysis.hxx"
+#include "persalys/PolynomialRegressionAnalysis.hxx"
 #include "persalys/StudyItem.hxx"
 #include "persalys/TranslationManager.hxx"
 #include "persalys/MonteCarloAnalysis.hxx"
@@ -69,7 +70,8 @@ void AnalysisItem::buildActions()
     appendAction(modifyAction_);
   }
   if (analysisType == "FunctionalChaosAnalysis" ||
-      analysisType == "KrigingAnalysis")
+      analysisType == "KrigingAnalysis" ||
+      analysisType == "PolynomialRegressionAnalysis")
   {
     convertAction_ = new QAction(tr("Convert metamodel into physical model"), this);
     convertAction_->setStatusTip(tr("Add the metamodel in the study tree"));
@@ -212,6 +214,7 @@ void AnalysisItem::appendMetaModelItem()
 {
   FunctionalChaosAnalysis * chaos = dynamic_cast<FunctionalChaosAnalysis*>(analysis_.getImplementation().get());
   KrigingAnalysis * kriging = dynamic_cast<KrigingAnalysis*>(analysis_.getImplementation().get());
+  PolynomialRegressionAnalysis * regression = dynamic_cast<PolynomialRegressionAnalysis*>(analysis_.getImplementation().get());
   if (chaos)
   {
     getParentStudyItem()->appendMetaModelItem(chaos->getResult().getMetaModel());
@@ -220,6 +223,10 @@ void AnalysisItem::appendMetaModelItem()
   {
     getParentStudyItem()->appendMetaModelItem(kriging->getResult().getMetaModel());
   }
+  else if (regression)
+  {
+    getParentStudyItem()->appendMetaModelItem(regression->getResult().getMetaModel());
+  }
 }
 
 
@@ -292,7 +299,7 @@ void AnalysisItem::update(Observable* /*source*/, const String& message)
   }
   else if (message == "progressValueChanged")
   {
-    // emit signal to AnalysisWindow to upate the progress bar
+    // emit signal to AnalysisWindow to update the progress bar
     emit progressValueChanged(analysis_.getProgressValue());
   }
   else if (message == "doeChanged" && convertAction_)
