@@ -2,7 +2,7 @@
 /**
  *  @brief QWizardPage to define simulation reliability analysis
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -89,7 +89,7 @@ CalibrationIntroPage::CalibrationIntroPage(QWidget * parent)
   methodLayout->addWidget(nonLinearLeastSquaresButton);
 
   // - Linear Gaussian
-  QRadioButton * linearGaussianButton = new QRadioButton(tr("Linear Gaussian") + " (BLUE)");
+  QRadioButton * linearGaussianButton = new QRadioButton(tr("Linear Gaussian"));
   registerField("linearGaussianButton", linearGaussianButton);
   methodGroup_->addButton(linearGaussianButton, CalibrationIntroPage::LinearGaussian);
   methodLayout->addWidget(linearGaussianButton);
