@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow to define a FMI physical model
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -55,6 +55,8 @@ FMIPhysicalModelWindow::FMIPhysicalModelWindow(PhysicalModelItem * item, QWidget
   , variablesTableModel_(0)
   , errorMessageLabel_(0)
 {
+  QScrollArea * scrollArea = new QScrollArea;
+  scrollArea->setWidgetResizable(true);
   QVBoxLayout * widgetLayout = new QVBoxLayout(this);
 
   widgetLayout->addWidget(new TitleLabel(tr("FMI model")));
@@ -62,6 +64,7 @@ FMIPhysicalModelWindow::FMIPhysicalModelWindow(PhysicalModelItem * item, QWidget
   tabWidget_ = new QTabWidget;
 
   QWidget * propertiesWidget = new QWidget;
+  scrollArea->setWidget(propertiesWidget);
   QVBoxLayout * propertiesLayout = new QVBoxLayout(propertiesWidget);
 
   // Widgets to load XML file
@@ -99,12 +102,24 @@ FMIPhysicalModelWindow::FMIPhysicalModelWindow(PhysicalModelItem * item, QWidget
   for (int i = 0; i < namesList.size(); ++ i)
     valuesList << QString(128, ' ');
 
-  propertiesTable_ = new ParametersTableView(namesList, valuesList, true, true);
+  propertiesTable_ = new ParametersTableView(namesList, valuesList, true, true, false);
   propertiesTable_->hide();
   propertiesLayout->addWidget(propertiesTable_);
+
+  CollapsibleGroupBox * advancedGroupBox = new CollapsibleGroupBox(tr("Advanced parameters"));
+  QHBoxLayout * typeLayout = new QHBoxLayout(advancedGroupBox);
+  QLabel *fmuTypeLabel = new QLabel(tr("FMU type"));
+  typeLayout->addWidget(fmuTypeLabel);
+  FMUTypeCombobox_ = new QComboBox;
+  FMUTypeCombobox_->addItems({ "auto", "ME", "CS" });
+  FMUTypeCombobox_->setCurrentText(getFMIPhysicalModel()->getFMUType().c_str());
+  typeLayout->addWidget(FMUTypeCombobox_);
+  typeLayout->addStretch();
+  propertiesLayout->addWidget(advancedGroupBox);
+
   propertiesLayout->addStretch();
 
-  tabWidget_->addTab(propertiesWidget, tr("Properties"));
+  tabWidget_->addTab(scrollArea, tr("Properties"));
 
   QWidget * variablesWidget = new QWidget;
 
@@ -188,11 +203,18 @@ FMIPhysicalModelWindow::FMIPhysicalModelWindow(PhysicalModelItem * item, QWidget
   ioCountLabel_ = new QLabel;
   QPushButton * evaluateOutputsButton = new QPushButton(QIcon(":/images/system-run.png"), tr("Check model"));
   evaluateOutputsButton->setToolTip(tr("Evaluate the outputs"));
-  connect(evaluateOutputsButton, SIGNAL(clicked(bool)), this, SLOT(evaluateOutputs()));
-  QHBoxLayout * evaluationLayout = new QHBoxLayout;
-  evaluationLayout->addWidget(ioCountLabel_);
-  evaluationLayout->addStretch();
-  evaluationLayout->addWidget(evaluateOutputsButton);
+  QLabel * timeInfo = new QLabel();
+  connect(evaluateOutputsButton, &QPushButton::clicked,  [=] (bool) {
+    timeInfo->clear();
+    evaluateOutputs();
+    if(physicalModel_.getEvalTime()>0)
+        timeInfo->setText(tr("Elapsed time") + ": " + QtOT::FormatDuration(physicalModel_.getEvalTime()));
+  });
+  QGridLayout * evaluationLayout = new QGridLayout;
+  evaluationLayout->addWidget(ioCountLabel_, 0, 0);
+  evaluationLayout->setColumnStretch(0,2);
+  evaluationLayout->addWidget(timeInfo, 1, 0);
+  evaluationLayout->addWidget(evaluateOutputsButton, 0, 1);
   variablesLayout->addLayout(evaluationLayout);
 
   // error message
@@ -280,11 +302,13 @@ void FMIPhysicalModelWindow::evaluateOutputs()
   if (!eval.getErrorMessage().empty())
   {
     errorMessageLabel_->setErrorMessage(eval.getErrorMessage().c_str());
+    physicalModel_.setEvalTime(0);
     return;
   }
   if (!outputSample.getSize())
   {
     errorMessageLabel_->setErrorMessage(tr("Not possible to evaluate the outputs"));
+    physicalModel_.setEvalTime(0);
     return;
   }
 
@@ -321,6 +345,7 @@ void FMIPhysicalModelWindow::selectImportFileDialogRequested()
       QApplication::setOverrideCursor(Qt::WaitCursor);
       try
       {
+        fmiModel->setFMUType(FMUTypeCombobox_->currentText().toStdString());
         fmiModel->setFMUFileName(fileName.toUtf8().data());
         errorMessageLabel_->reset();
       }
@@ -411,7 +436,6 @@ void FMIPhysicalModelWindow::updateFilters()
 
 void FMIPhysicalModelWindow::updateIOCount()
 {
-  int disabledVar = 0;
   int inVar = 0;
   int outVar = 0;
   Indices io(variablesTableModel_->getIO());
@@ -419,9 +443,6 @@ void FMIPhysicalModelWindow::updateIOCount()
   {
     switch(io[i])
     {
-      case 0:
-        ++ disabledVar;
-        break;
       case 1:
         ++ inVar;
         break;
@@ -951,9 +972,9 @@ bool DataFilterProxyModel::filterAcceptsRow(int sourceRow,
 
 
 TreeItem::TreeItem(const QList<QVariant> &data, TreeItem *parent)
+ : m_itemData(data)
+ , m_parentItem(parent)
 {
-  m_parentItem = parent;
-  m_itemData = data;
 }
 
 TreeItem::~TreeItem()
@@ -971,6 +992,16 @@ TreeItem *TreeItem::child(int row)
   return m_childItems.value(row);
 }
 
+void TreeItem::setChild(int row, TreeItem * child)
+{
+  m_childItems[row] = child;
+}
+
+void TreeItem::clearChildren()
+{
+  m_childItems.removeAll(nullptr);
+}
+
 int TreeItem::childCount() const
 {
   return m_childItems.count();
@@ -986,11 +1017,21 @@ QVariant TreeItem::data(int column) const
   return m_itemData.value(column);
 }
 
+void TreeItem::setData(const QList<QVariant> &data)
+{
+  m_itemData = data;
+}
+
 TreeItem *TreeItem::parentItem()
 {
   return m_parentItem;
 }
 
+void TreeItem::setParentItem(TreeItem * parentItem)
+{
+  m_parentItem = parentItem;
+}
+
 int TreeItem::row() const
 {
   if (m_parentItem)
@@ -1002,17 +1043,12 @@ int TreeItem::row() const
 TreeModel::TreeModel(const QString & /*file*/, QObject *parent)
   : QAbstractItemModel(parent)
 {
-  QList<QVariant> rootData;
-  rootData << tr("Variables");
+  QList<QVariant> rootData = {tr("Variables")};
   rootItem_ = new TreeItem(rootData);
-//     setupModelData(file, rootItem);
 }
 
 void TreeModel::setVariableNames(const Description & variableNames)
 {
-//   QList<QVariant> rootData;
-//   rootData << "Title" << "Summary";
-//   rootItem_ = new TreeItem(rootData);
   setupModelData(variableNames);
 }
 
@@ -1114,8 +1150,7 @@ void TreeModel::setupModelData(const Description & variableNames)
   if (rootItem_->childCount())
   {
     delete rootItem_;
-    QList<QVariant> rootData;
-    rootData << "Variable";
+    QList<QVariant> rootData = {"Variable"};
     rootItem_ = new TreeItem(rootData);
   }
 
@@ -1140,15 +1175,49 @@ void TreeModel::setupModelData(const Description & variableNames)
       else
       {
         // create new node
-        QList<QVariant> columnData;
-        columnData << chunk;
+        QList<QVariant> columnData = { chunk };
         newChild = new TreeItem(columnData, currentParent);
         currentParent->appendChild(newChild);
       }
       currentParent = newChild;
     }
   }
+
+  // simplify unnecessary depth in tree by merging nodes with 1 child
+  for (int i = 0; i < rootItem_->childCount(); ++ i)
+    MergeNodes(rootItem_->child(i));
+
   endResetModel();
 }
 
+void TreeModel::MergeNodes(TreeItem * node)
+{
+  while (node->childCount() == 1)
+  {
+    TreeItem *child = node->child(0);
+    const QString mergedString = node->data(0).toString() + "." + child->data(0).toString();
+    QList<QVariant> columnData = { mergedString };
+    node->setData(columnData);
+    // grand child 0
+    if (child->childCount())
+      node->setChild(0, child->child(0));
+    else
+    {
+      node->setChild(0, nullptr);
+      node->clearChildren();
+    }
+    // grand child 1-n
+    for (int i = 1; i < child->childCount(); ++ i)
+      node->appendChild(child->child(i));
+    for (int i = 0; i < child->childCount(); ++ i)
+    {
+      child->child(i)->setParentItem(node);
+      child->setChild(i, nullptr); // avoid ctor killing children
+    }
+    delete child;
+  }
+  for (int i = 0; i < node->childCount(); ++ i)
+    MergeNodes(node->child(i));
+}
+
 }
