@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for the results of an evaluation of the model
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -346,7 +346,7 @@ void FieldCentralTendencyResultWindow::addDecompositionTab()
 
         // CDF
         PlotWidget * cdfPlot = new PlotWidget(tr("distributionCDF"));
-        cdfPlot->plotHistogram(xi_sample.getMarginal(i), 1);
+        cdfPlot->plotHistogram(xi_sample.getMarginal(i), PlotWidget::CDF);
         cdfPlot->plotCurve(fittedDistribution.drawCDF().getDrawable(0).getData());
         cdfPlot->setTitle(tr("CDF:") + " " + QString("ξ%1").arg(i));
         cdfPlot->setAxisTitle(QwtPlot::xBottom, QString("ξ%1").arg(i));
@@ -806,7 +806,7 @@ void FieldModelEvaluationResultWidget::addParaviewWidgetsTabs()
 
       bagChartStackedWidget->addWidget(new WidgetBoundToDockWidget(bagChartWidget, settingWidget, this));
 
-      String aStr = (OSS() << inPVTable->getProxy() << bagChartWidget->getProxy()).str();
+      aStr = (OSS() << inPVTable->getProxy() << bagChartWidget->getProxy()).str();
       linksModel->addSelectionLink(aStr.c_str(), fBagChartWidget->getProxy(), outPVGraph->getProxy());
     }
   }
