@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for the results of functional chaos
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -123,7 +123,7 @@ void FunctionalChaosResultWindow::buildInterface()
       generalStackedWidget->addWidget(generalTableView);
     }
     summaryWidgetLayout->addWidget(generalStackedWidget);
-    
+
     QGroupBox * basisGroupBox = new QGroupBox(tr("Polynomial basis"));
     QVBoxLayout * basisGroupBoxLayout = new QVBoxLayout(basisGroupBox);
     ResizableStackedWidget * basisStackedWidget = new ResizableStackedWidget;
@@ -323,7 +323,7 @@ void FunctionalChaosResultWindow::buildInterface()
   tabLayout->addWidget(plotsStackedWidget);
 
   tabWidget->addTab(plotsStackedWidget, tr("Adequation"));
-  
+
   // third tab : SOBOL INDICES --------------------------------
   if (result_.getSobolResult().getOutputNames().getSize() == nbOutputs)
   {
@@ -404,7 +404,7 @@ void FunctionalChaosResultWindow::buildInterface()
         MetaModelValidationWidget * validationWidget = new MetaModelValidationWidget(result_.getValidations()[i],
             outputSample,
             j,
-            tr("Q2"),
+            tr("Q2 LOO"),
             this);
         plotStackedWidget->addWidget(validationWidget);
       }
