@@ -2,7 +2,7 @@
 /**
  *  @brief QWidget for the inference results
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,6 +20,7 @@
  */
 #include "persalys/InferenceResultWidget.hxx"
 
+#include "persalys/InferenceAnalysis.hxx"
 #include "persalys/ResizableStackedWidget.hxx"
 #include "persalys/RadioButtonDelegate.hxx"
 #include "persalys/WidgetBoundToDockWidget.hxx"
@@ -55,6 +56,7 @@ InferenceResultWidget::InferenceResultWidget(const bool displayPDF_QQPlot, QWidg
   , pdfPlot_(0)
   , cdfPlot_(0)
   , qqPlot_(0)
+  , survPlot_(0)
 {
   buildInterface();
 }
@@ -121,10 +123,14 @@ void InferenceResultWidget::buildInterface()
     // --- cdf
     cdfPlot_ = new PlotWidget(tr("distributionCDF"));
     pdf_cdfStackedWidget->addWidget(cdfPlot_);
+    // --- survival function
+    survPlot_ = new PlotWidget(tr("survivalFunction"));
+    pdf_cdfStackedWidget->addWidget(survPlot_);
     // --- GraphConfigurationWidget
     QVector<PlotWidget*> listpdf_cdfPlot;
     listpdf_cdfPlot.append(pdfPlot_);
     listpdf_cdfPlot.append(cdfPlot_);
+    listpdf_cdfPlot.append(survPlot_);
     pdf_cdfPlotSettingWidget_ = new PDFGraphSetting(listpdf_cdfPlot, PDFGraphSetting::Result, this);
     connect(pdf_cdfPlotSettingWidget_, SIGNAL(currentPlotChanged(int)), pdf_cdfStackedWidget, SLOT(setCurrentIndex(int)));
 
@@ -201,7 +207,6 @@ void InferenceResultWidget::updateDistributionTable(const double level, const In
   distTableModel_->setNotEditableHeaderItem(0, 0, tr("Distribution"));
   distTableModel_->setNotEditableHeaderItem(0, 1, tr("Bayesian\nInformation\nCriterion"));
   distTableModel_->setData(distTableModel_->index(0, 1), tr("Lower BIC value is better"), Qt::ToolTipRole);
-  distTableModel_->setNotEditableHeaderItem(0, 2, tr("Kolmogorov-Smirnov"));
   distTableModel_->setNotEditableHeaderItem(1, 2, tr("p-value"));
   distTableModel_->setNotEditableHeaderItem(1, 3, tr("Acceptation") + "\n(" + QString::number(level) + ")");
   distTableView_->setSpan(0, 0, 2, 1);
@@ -210,6 +215,11 @@ void InferenceResultWidget::updateDistributionTable(const double level, const In
   // table
   // -- get results of the variable
   currentFittingTestResult_ = result.getFittingTestResultForVariable(variableName.toStdString());
+  // check test type and set header title
+  if(currentFittingTestResult_.getTestType() == InferenceAnalysis::Kolmogorov)
+    distTableModel_->setNotEditableHeaderItem(0, 2, tr("Kolmogorov-Smirnov"));
+  else
+    distTableModel_->setNotEditableHeaderItem(0, 2, tr("Lilliefors"));
   // BIC values
   Point bicValues(currentFittingTestResult_.getBICResults());
   // number of tests
@@ -240,11 +250,11 @@ void InferenceResultWidget::updateDistributionTable(const double level, const In
     {
       distTableModel_->setNotEditableItem(cellRow, 1, bicValues[indices[i]], 3);
 
-      const Scalar pValue = currentFittingTestResult_.getKolmogorovTestResults()[indices[i]].getPValue();
+      const Scalar pValue = currentFittingTestResult_.getTestResults()[indices[i]].getPValue();
       distTableModel_->setNotEditableItem(cellRow, 2, pValue, 3);
 
       // if accepted
-      if (currentFittingTestResult_.getKolmogorovTestResults()[indices[i]].getBinaryQualityMeasure())
+      if (currentFittingTestResult_.getTestResults()[indices[i]].getBinaryQualityMeasure())
       {
         distTableModel_->setNotEditableItem(cellRow, 3, tr("yes"), Qt::green);
       }
@@ -276,7 +286,6 @@ void InferenceResultWidget::updateDistributionTable(const double level, const In
   distTableModel_->setItem(0, 2, new QStandardItem);
   distTableView_->resizeToContents();
   const int section2Size = distTableView_->horizontalHeader()->sectionSize(2);
-  distTableModel_->setNotEditableHeaderItem(0, 2, tr("Kolmogorov-Smirnov"));
   distTableView_->setSpan(0, 2, 1, 2);
   const int subTitlesWidth = distTableView_->horizontalHeader()->sectionSize(1) + distTableView_->horizontalHeader()->sectionSize(2);
   const int widthCorrection = titleWidth - subTitlesWidth;
@@ -345,7 +354,10 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
   if (infoButton_)
     infoButton_->show();
 
-  distParamTableModel_->setColumnCount(2);
+  if (currentFittingTestResult_.getParamConfidenceInterval().getSize())
+    distParamTableModel_->setColumnCount(4);
+  else
+    distParamTableModel_->setColumnCount(2);
 
   // fill table
   // -- used font for titles
@@ -355,6 +367,7 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
   Distribution distribution;
   int row = -1;
 
+
   if (current.isValid())
   {
     // -- get distribution
@@ -364,6 +377,11 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
     // -- set parameters
     distParamTableModel_->setNotEditableItem(++row, 0, tr("Parameters"));
     distParamTableView_->setSpan(row, 0, 1, 2);
+    if (currentFittingTestResult_.getParamConfidenceInterval().getSize())
+    {
+      distParamTableView_->setSpan(row, 2, 1, 2);
+      distParamTableModel_->setNotEditableItem(row, 2, tr("Parameters\nconfidence interval"));
+    }
     distParamTableModel_->setData(distParamTableModel_->index(row, 0), font, Qt::FontRole);
 
     const PointWithDescription parameters = DistributionDictionary::GetParametersCollection(distribution)[0];
@@ -372,6 +390,12 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
       const QString param(TranslationManager::GetTranslatedDistributionParameterName(parameters.getDescription()[i]));
       distParamTableModel_->setNotEditableHeaderItem(++row, 0, param);
       distParamTableModel_->setNotEditableItem(row, 1, parameters[i]);
+      if (currentFittingTestResult_.getParamConfidenceInterval().getSize())
+      {
+        const Interval paramBounds = currentFittingTestResult_.getParamConfidenceInterval()[variant.value<int>()];
+        distParamTableModel_->setNotEditableItem(row, 2, paramBounds.getLowerBound()[i]);
+        distParamTableModel_->setNotEditableItem(row, 3, paramBounds.getUpperBound()[i]);
+      }
     }
   }
   distParamTableModel_->setNotEditableItem(++row, 0, tr("Moments"));
@@ -394,7 +418,7 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
     {
       distParamTableModel_->setNotEditableItem(++row, 1, distribution.getSkewness()[0]);
     }
-    catch (std::exception & ex)
+    catch (const std::exception &)
     {
       distParamTableModel_->setNotEditableItem(++row, 1, "-");
     }
@@ -402,7 +426,7 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
     {
       distParamTableModel_->setNotEditableItem(++row, 1, distribution.getKurtosis()[0]);
     }
-    catch (std::exception & ex)
+    catch (const std::exception &)
     {
       distParamTableModel_->setNotEditableItem(++row, 1, "-");
     }
@@ -435,6 +459,11 @@ void InferenceResultWidget::updateGraphs(QModelIndex current)
     cdfPlot_->clear();
     qqPlot_->clear();
   }
+  if(survPlot_ && pdf_cdfPlotSettingWidget_)
+  {
+    pdf_cdfPlotSettingWidget_->getCurrentPlotIndex() == 2 ? survPlot_->show() : survPlot_->hide();
+    survPlot_->clear();
+  }
 
   // update
   const QVariant variant = distTableModel_->data(distTableModel_->index(current.row(), 0), Qt::UserRole);
@@ -491,7 +520,7 @@ void InferenceResultWidget::updateGraphs(QModelIndex current)
   }
   cdfPlot_->plotCurve(F_nx, QPen(Qt::blue, 2));
 
-  // compute Kolmogorov–Smirnov statistic : D_n = sup |F_n(x) - F(x)|
+  // compute fitting test statistic : D_n = sup |F_n(x) - F(x)|
   const Sample Fx(distribution.computeCDF(F_nx.getMarginal(0)));
   Sample KSStatistic(2, 2);
   for (UnsignedInteger i = 0; i < F_nx.getSize(); ++i)
@@ -505,15 +534,58 @@ void InferenceResultWidget::updateGraphs(QModelIndex current)
     }
   }
   cdfPlot_->plotCurve(KSStatistic, QPen(Qt::red, 2));
-  cdfPlot_->setTitle(tr("CDF") + ": " + distName + " " + tr("(Kolmogorov–Smirnov statistic=%1)").arg(std::abs(KSStatistic(0, 1) - KSStatistic(1, 1))));
+  QString testName;
+  if(currentFittingTestResult_.getTestType() == InferenceAnalysis::Kolmogorov)
+    testName = QString(tr("Kolmogorov-Smirnov"));
+  else
+    testName = QString(tr("Lilliefors"));
+
+  cdfPlot_->setTitle(tr("CDF") + ": " + distName + " ("
+                     + testName + " " + tr("statistic=%1)").arg(std::abs(KSStatistic(0, 1) - KSStatistic(1, 1))));
 
   // -- qq plot
   Graph qqPlotGraph(VisualTest::DrawQQplot(currentFittingTestResult_.getValues(), distribution));
   qqPlot_->setTitle(tr("Q-Q Plot") + ": " + distName);
-  qqPlot_->setAxisTitle(QwtPlot::yLeft, tr("Data quantiles"));
-  qqPlot_->setAxisTitle(QwtPlot::xBottom, tr("%1 theoretical quantiles").arg(distName));
+  qqPlot_->setAxisTitle(QwtPlot::xBottom, tr("Data quantiles"));
+  qqPlot_->setAxisTitle(QwtPlot::yLeft, tr("%1 theoretical quantiles").arg(distName));
   qqPlot_->plotCurve(qqPlotGraph.getDrawable(1).getData(), QPen(Qt::blue, 5), QwtPlotCurve::Dots);
   qqPlot_->plotCurve(qqPlotGraph.getDrawable(0).getData());
+
+  // -- survival function plot
+  if(survPlot_)
+  {
+    survPlot_->plotSurvivalCurve(distribution);
+    const Sample S_nxOT(u.drawSurvivalFunction(xmin, xmax).getDrawable(0).getData());
+    Sample S_nx(0, 2);
+    for (UnsignedInteger i = 0; i < S_nxOT.getSize(); ++i)
+    {
+      S_nx.add(S_nxOT[i]);
+      if (i < S_nxOT.getSize() - 1)
+      {
+        Point interPt(2);
+        interPt[0] = S_nxOT(i+1, 0);
+        interPt[1] = S_nxOT(i, 1);
+        S_nx.add(interPt);
+      }
+    }
+    survPlot_->plotCurve(S_nx, QPen(Qt::blue, 2));
+    // compute fitting test statistic : D_n = sup |S_n(x) - S(x)|
+    const Sample Sx(distribution.computeSurvivalFunction(S_nx.getMarginal(0)));
+    KSStatistic = Sample(2, 2);
+    for (UnsignedInteger i = 0; i < S_nx.getSize(); ++i)
+    {
+      if (std::abs(S_nx(i, 1) - Sx(i, 0)) > std::abs(KSStatistic(0, 1) - KSStatistic(1, 1)))
+      {
+        KSStatistic(0, 1) = S_nx(i, 1);
+        KSStatistic(1, 1) = Sx(i, 0);
+        KSStatistic(0, 0) = S_nx(i, 0);
+        KSStatistic(1, 0) = S_nx(i, 0);
+      }
+    }
+    survPlot_->plotCurve(KSStatistic, QPen(Qt::red, 2));
+    survPlot_->setTitle(tr("Survival function") + ": " + distName + " ("
+                       + testName + " " + tr("statistic=%1)").arg(std::abs(KSStatistic(0, 1) - KSStatistic(1, 1))));
+  }
 }
 
 
