@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for the results of functional chaos
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -116,7 +116,7 @@ void KrigingResultWindow::buildInterface()
     }
 
     // trend coef
-    QString trendCoefText = QtOT::PointToString(result_.getKrigingResultCollection()[i].getTrendCoefficients()[0]);
+    QString trendCoefText = QtOT::PointToString(result_.getKrigingResultCollection()[i].getTrendCoefficients());
     ParametersWidget * trendCoefTable = new ParametersWidget(tr("Trend"), QStringList() << tr("Trend coefficients"), QStringList() << trendCoefText, true, true);
     resultWidgetLayout->addWidget(trendCoefTable);
     resultWidgetLayout->setRowStretch(optimizeParameters_ ? 2 : 1, 1);
@@ -147,7 +147,7 @@ void KrigingResultWindow::buildInterface()
   tabLayout->addWidget(plotsStackedWidget);
 
   tabWidget->addTab(tab, tr("Adequation"));
-  
+
   // third tab : VALIDATION --------------------------------
   if (result_.getValidations().size())
   {
@@ -196,7 +196,7 @@ void KrigingResultWindow::buildInterface()
         MetaModelValidationWidget * validationWidget = new MetaModelValidationWidget(result_.getValidations()[i],
             outputSample,
             j,
-            tr("Q2"),
+            tr("Q2 LOO"),
             this);
         plotStackedWidget->addWidget(validationWidget);
       }
