@@ -2,7 +2,7 @@
 /**
  *  @brief QWizard to define a metamodel analysis
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,7 +72,7 @@ void MetaModelAnalysisWizard::buildInterface()
   setWindowTitle(tr("Metamodel"));
   docLink_ = "user_manual/graphical_interface/data_analysis/user_manual_data_analysis.html#metamodelwizard";
 
-  // intro page : doe/ouputs/method
+  // intro page : doe/outputs/method
   introPage_ = new MetaModelIntroPage(this);
   setPage(Page_Intro, introPage_);
 
@@ -83,7 +83,7 @@ void MetaModelAnalysisWizard::buildInterface()
   // chaos page
   functionalChaosPage_ = new FunctionalChaosPage(this);
   setPage(Page_ChaosMethod, functionalChaosPage_);
-  connect(introPage_, SIGNAL(designOfExperimentChanged(DesignOfExperiment)), functionalChaosPage_, SLOT(updateInputSampleSize(DesignOfExperiment)));
+  connect(introPage_, SIGNAL(designOfExperimentChanged(DesignOfExperiment)), functionalChaosPage_, SLOT(updateInputSampleSizeAndDimension(DesignOfExperiment)));
 
   // kriging page
   krigingPage_ = new KrigingPage(this);
