@@ -2,7 +2,7 @@
 /**
  *  @brief QWizard to export a metamodel as physical model
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -52,9 +52,9 @@ namespace PERSALYS
         StudyImplementation * study = dynamic_cast<StudyImplementation*>(obs);
         Q_ASSERT(study);
         for (UnsignedInteger i = 0; i < study->getAnalyses().getSize(); ++i) {
-          const MetaModelAnalysis * analysis = dynamic_cast<const MetaModelAnalysis*>(study->getAnalyses()[i].getImplementation().get());
-          if (analysis && analysis->hasValidResult()) {
-            QStandardItem * comboItem = new QStandardItem(QString::fromUtf8(analysis->getName().c_str()));
+          const MetaModelAnalysis * mmanalysis = dynamic_cast<const MetaModelAnalysis*>(study->getAnalyses()[i].getImplementation().get());
+          if (mmanalysis && mmanalysis->hasValidResult()) {
+            QStandardItem * comboItem = new QStandardItem(QString::fromUtf8(mmanalysis->getName().c_str()));
             comboItem->setData(QVariant::fromValue(study->getAnalyses()[i]));
             mmsComboBoxModel_->appendRow(comboItem);
           }
