@@ -2,7 +2,7 @@
 /**
  *  @brief QMdiSubWindow for metamodels
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,7 @@
 #include "persalys/MetaModelWindow.hxx"
 
 #include "persalys/PhysicalModelWindowWidget.hxx"
+#include "persalys/CheckModelButtonGroup.hxx"
 
 #include <QVBoxLayout>
 
@@ -35,6 +36,16 @@ MetaModelWindow::MetaModelWindow(PhysicalModelItem * item, QWidget * parent)
 
   widgetLayout->addWidget(new TitleLabel(tr("Metamodel")));
 
-  widgetLayout->addWidget(new PhysicalModelWindowWidget(item));
+  PhysicalModelWindowWidget *widget = new PhysicalModelWindowWidget(item);
+  widgetLayout->addWidget(widget);
+
+  // buttons
+  CheckModelButtonGroup *buttons = new CheckModelButtonGroup;
+  connect(buttons, SIGNAL(evaluateOutputsRequested()), widget, SIGNAL(evaluateOutputsRequested()));
+  connect(buttons, SIGNAL(evaluateGradientRequested()), widget, SIGNAL(evaluateGradientRequested()));
+  connect(widget, SIGNAL(errorMessageChanged(QString)), buttons->getErrorMessageLabel(), SLOT(setErrorMessage(QString)));
+  connect(widget, SIGNAL(resetMessageLabel()), buttons->getErrorMessageLabel(), SLOT(reset()));
+  widgetLayout->addWidget(buttons);
+
 }
 }
