@@ -2,7 +2,7 @@
 /**
  *  @brief QWizardPage to define the method of sensitivity analysis
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,8 +26,6 @@
 #include "persalys/QtTools.hxx"
 #include "persalys/DocumentationToolButton.hxx"
 
-#include <openturns/NLopt.hxx>
-
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QRadioButton>
@@ -121,7 +119,10 @@ void OptimizationAlgoPage::initialize(OptimizationAnalysis& analysis)
   algoTableModel_->setHorizontalHeaderItem(3, new QStandardItem(tr("Doc")));
 
   errorMessageLabel_->reset();
-  solverNames_ = OptimizationAnalysis::GetSolverNames(analysis.getBounds(), analysis.getVariablesType());
+  solverNames_ = OptimizationAnalysis::GetSolverNames(analysis.getBounds(),
+                                                      analysis.getVariablesType(),
+                                                      analysis.getEqualityConstraints(),
+                                                      analysis.getInequalityConstraints());
 
   for (UnsignedInteger i = 0; i < solverNames_.getSize(); ++i) {
     algoTableModel_->setNotEditableItem(i, 0, solverNames_[i].c_str());
