@@ -2,7 +2,7 @@
 /**
  *  @brief QWidget to visualize the variables of the physical model
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,6 +27,7 @@
 #include "persalys/InputTableModel.hxx"
 #include "persalys/OutputTableModel.hxx"
 #include "persalys/DifferentiationTableModel.hxx"
+#include "persalys/GradientTableModel.hxx"
 #include "persalys/FieldModelEvaluation.hxx"
 #include "persalys/FieldModelEvaluationResultWindow.hxx"
 
@@ -35,7 +36,6 @@
 #include <QScrollBar>
 #include <QGroupBox>
 #include <QVBoxLayout>
-#include <QPushButton>
 #include <QCheckBox>
 #include <QScrollArea>
 #include <QSpinBox>
@@ -52,7 +52,6 @@ PhysicalModelWindowWidget::PhysicalModelWindowWidget(PhysicalModelItem * item)
   , isFirstPaint_(true)
   , inputTableView_(0)
   , outputTableView_(0)
-  , errorMessageLabel_(0)
   , indexParamLabel_(0)
 {
   connect(item, SIGNAL(numberInputsChanged()), this, SIGNAL(updateInputTableData()));
@@ -152,21 +151,16 @@ void PhysicalModelWindowWidget::buildInterface()
   // buttons
   QHBoxLayout * outputButtonsLayout = new QHBoxLayout;
 
-  // button Evaluate outputs -------------------------------------------
-  QPushButton * evaluateOutputsButton = new QPushButton(QIcon(":/images/system-run.png"), tr("Check model"));
-  evaluateOutputsButton->setToolTip(tr("Evaluate the outputs"));
   QLabel * timeInfo = new QLabel();
-  connect(evaluateOutputsButton, &QPushButton::clicked,
-          [=] () {
-            timeInfo->clear();
-            evaluateOutputs();
-            if(physicalModel_.getEvalTime()>0)
-              timeInfo->setText(tr("Elapsed time") + ": " + QtOT::FormatDuration(physicalModel_.getEvalTime()));
-          });
-  outputButtonsLayout->addWidget(evaluateOutputsButton);
   outputButtonsLayout->addWidget(timeInfo);
   outputsLayout->addLayout(outputButtonsLayout);
   outputButtonsLayout->addStretch();
+  connect(this, &PhysicalModelWindowWidget::evaluateOutputsRequested, [=] () {
+      timeInfo->clear();
+      evaluateOutputs();
+      setCurrentIndex(0);
+      if(physicalModel_.getEvalTime()>0)
+        timeInfo->setText(tr("Elapsed time") + ": " + QtOT::FormatDuration(physicalModel_.getEvalTime()));});
 
   // buttons Add/Remove output
   if (physicalModel_.getImplementation()->getClassName().find("Symbolic") != std::string::npos)
@@ -198,11 +192,9 @@ void PhysicalModelWindowWidget::buildInterface()
   }
 
   // - error message label
-  errorMessageLabel_ = new TemporaryLabel;
-  vbox->addWidget(errorMessageLabel_);
-  connect(this, SIGNAL(resetMessageLabel()), errorMessageLabel_, SLOT(reset()));
-  connect(inputTableModel, SIGNAL(errorMessageChanged(QString)), errorMessageLabel_, SLOT(setErrorMessage(QString)));
-  connect(outputTableModel, SIGNAL(errorMessageChanged(QString)), errorMessageLabel_, SLOT(setErrorMessage(QString)));
+  connect(inputTableModel, SIGNAL(errorMessageChanged(QString)), this, SIGNAL(errorMessageChanged(QString)));
+  connect(outputTableModel, SIGNAL(errorMessageChanged(QString)), this, SIGNAL(errorMessageChanged(QString)));
+
 
   addTab(scrollArea, tr("Definition"));
 
@@ -236,6 +228,31 @@ void PhysicalModelWindowWidget::buildInterface()
 
     vbox->addWidget(differentiationTableView);
 
+    label = new QLabel(tr("Gradient values"));
+    vbox->addWidget(label);
+
+    CopyableTableView * gradientTableView = new CopyableTableView;
+    gradientTableView->horizontalHeader()->setStretchLastSection(true);
+
+    GradientTableModel * gradientTableModel  = new GradientTableModel(physicalModel_, gradientTableView);
+    gradientTableView->setModel(gradientTableModel);
+
+    // connections
+    connect(this, SIGNAL(updateInputTableData()), gradientTableModel, SLOT(updateData()));
+    connect(this, SIGNAL(updateOutputTableData()), gradientTableModel, SLOT(updateData()));
+
+    connect(inputTableModel, SIGNAL(inputNumberChanged()), gradientTableModel, SLOT(updateData()));
+    connect(inputTableModel, SIGNAL(inputNameChanged()), gradientTableModel, SLOT(updateData()));
+
+    connect(outputTableModel, SIGNAL(dataChanged(QModelIndex, QModelIndex)), gradientTableModel, SLOT(updateData()));
+    connect(gradientTableModel, SIGNAL(errorMessageChanged(QString)), this, SIGNAL(errorMessageChanged(QString)));
+
+    connect(this, &PhysicalModelWindowWidget::evaluateGradientRequested, [=] () {
+        gradientTableModel->evaluateGradient();
+        setCurrentIndex(1);});
+
+    vbox->addWidget(gradientTableView);
+
     addTab(tab, tr("Differentiation"));
   }
 }
@@ -336,7 +353,7 @@ void PhysicalModelWindowWidget::evaluateOutputs()
     {
       eval.run();
     }
-    catch (std::exception& ex)
+    catch (const std::exception &)
     {
       // do nothing
     }
@@ -347,13 +364,13 @@ void PhysicalModelWindowWidget::evaluateOutputs()
     // check
     if (!eval.getErrorMessage().empty())
     {
-      errorMessageLabel_->setErrorMessage(eval.getErrorMessage().c_str());
+      emit errorMessageChanged(QString(eval.getErrorMessage().c_str()));
       physicalModel_.setEvalTime(0);
       return;
     }
     if (!outputSample.getSize())
     {
-      errorMessageLabel_->setErrorMessage(tr("Not possible to evaluate the outputs"));
+      emit errorMessageChanged(tr("Not possible to evaluate the outputs"));
       physicalModel_.setEvalTime(0);
       return;
     }
@@ -378,17 +395,18 @@ void PhysicalModelWindowWidget::evaluateOutputs()
     }
     catch (std::exception& ex)
     {
-      errorMessageLabel_->setErrorMessage(tr("Not possible to evaluate the outputs %1").arg(ex.what()));
+      emit errorMessageChanged(tr("Not possible to evaluate the outputs %1").arg(ex.what()));
       physicalModel_.setEvalTime(0);
       return;
     }
     physicalModel_.setEvalTime(eval.getElapsedTime());
   }
-  errorMessageLabel_->reset();
+  emit resetMessageLabel();
 }
 
 void PhysicalModelWindowWidget::updateIndexParamLabel()
 {
   indexParamLabel_->setText(tr("Index parameter : %1").arg(physicalModel_.getMeshModel().getIndexParameters()[0].getName().c_str()));
 }
+
 }
