@@ -2,7 +2,7 @@
 /**
  *  @brief QObject managing study objects
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -388,9 +388,7 @@ bool StudyManager::save(StudyItem* studyItem)
   const QFileInfo file(QString::fromUtf8(studyItem->getStudy().getFileName().c_str()));
   if (file.exists())
   {
-    QApplication::setOverrideCursor(Qt::WaitCursor);
-    studyItem->getStudy().save(QDir::toNativeSeparators(file.absoluteFilePath()).toUtf8().data());
-    QApplication::restoreOverrideCursor();
+    studyItem->save(QDir::toNativeSeparators(file.absoluteFilePath()).toUtf8().data());
     emit recentFilesListChanged(file.absoluteFilePath().toUtf8().data());
     return true;
   }
