@@ -2,7 +2,7 @@
 /**
  *  @brief QDoubleSpinBox
  *
- *  Copyright 2015-2022 EDF-Phimeca
+ *  Copyright 2015-2023 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -587,7 +587,7 @@ bool DoubleSpinBox::isIntermediateValueHelper(qint64 num, qint64 min, qint64 max
   else
   {
     tmp = qAbs(num);
-    for (int i = 0; tmp > 0; ++i)
+    while (tmp > 0)
     {
       digits[numDigits++] = tmp % 10;
       tmp /= 10;
