@@ -31,6 +31,7 @@ result = analysis.getResult()
 print("result=", result)
 print("PDF=", result.getPDF())
 print("CDF=", result.getCDF())
+print("SurvivalFunction=", result.getSurvivalFunction())
 print("outliers=", result.getOutliers())
 
 # Comparaison
@@ -100,3 +101,10 @@ except Exception:
     # fr locale not available
     pass
 os.remove(filename)
+
+filename = "DonneesLatin1.csv"
+model4 = persalys.DataModel(
+    "myDataModel4", filename, [0, 1, 2, 3], [4, 5])
+
+myStudy.add(model4)
+print(model4.getSampleFromFile().getDescription())
