@@ -30,6 +30,14 @@ anOTStudy.add(aDesign2)
 aDesign2.run()
 print("outs=", aDesign2.getResult().getDesignOfExperiment().getOutputSample())
 
+# Design of Experiment - imported - already evaluated##
+aDesign2_1 = persalys.ImportedDesignOfExperiment("aDesign_2_1", model, filename, [0, 2], [1])
+anOTStudy.add(aDesign2_1)
+
+# Considered already evaluated, do not run it
+# aDesign2_1.run()
+print("outs=", aDesign2_1.getResult().getDesignOfExperiment().getOutputSample())
+
 # Design of Experiment ##
 aDesign3 = persalys.ProbabilisticDesignOfExperiment(
     "aDesign_3", model, 10, "QUASI_MONTE_CARLO"
@@ -115,6 +123,24 @@ anOTStudy2.add(aDesign10)
 aDesign10.run()
 print("outs=", aDesign10.getResult().getDesignOfExperiment().getOutputSample())
 
+# Design of Experiment with failed points ##
+code = "import time\ndef _exec(X0,X1):\n    Y0 = 1/(X0+X1)\n    return Y0\n"
+model2 = persalys.PythonPhysicalModel("aModelPhys2", [X0, X1], [Y0], code)
+anOTStudy.add(model2)
+
+aDesign11 = persalys.GridDesignOfExperiment("aDesign_11", model2, [[-3, 0, 3], [-3, 0, 3]])
+anOTStudy.add(aDesign11)
+
+aDesign11.run()
+print("outs=", aDesign11.getErrorDescription())
+
+model2.setParallel(False)
+aDesign12 = persalys.GridDesignOfExperiment("aDesign_12", model2, [[-3, 0, 3], [-3, 0, 3]])
+anOTStudy.add(aDesign12)
+
+aDesign12.run()
+print("outs=", aDesign12.getErrorDescription())
+
 # script
 script = anOTStudy.getPythonScript()
 print(script)
